# Colour Print Python
Short print statements to print in colour and bold in Python

`pip install colour-print`

```
from colour_print import *
p("Normal")
pr("Red")
pg("Green")
py("Yellow")
pb("Blue")
```

For Windows, probably need to install `pip install colorama`
